@@ -1,7 +1,7 @@
 /* bsect.c  -  Boot sector handling */
 /*
 Copyright 1992-1998 Werner Almesberger.
-Copyright 1999-2004 John Coffman.
+Copyright 1999-2005 John Coffman.
 All rights reserved.
 
 Licensed under the terms contained in the file 'COPYING' in the 
@@ -328,7 +328,7 @@ static void hash_password(char *password, int crcval[])
 	
 #ifdef SHS_PASSWORDS
 	shsInit();
-	shsUpdate(password, i);
+	shsUpdate((BYTE*)password, i);
 	shsFinal();
 #endif
 	for (j=0; j<MAX_PW_CRC; j++) {
@@ -975,7 +975,7 @@ static int get_image(char *name,char *label,IMAGE_DESCR *descr)
     }
     if (strchr(label,' ')) die("Image name, label, or alias contains a blank character: '%s'", label);
     if (strlen(label) > MAX_IMAGE_NAME) die("Image name, label, or alias is too long: '%s'",label);
-    for (uch=label; *uch; uch++) {
+    for (uch=(unsigned char*)label; *uch; uch++) {
 	if (*uch<' ')  die("Image name, label, or alias contains an illegal character: '%s'", label);
     }
     for (other = image_base; other <= image; other++) {
@@ -1275,6 +1275,22 @@ static void unbootable(void)
 }
 
 
+#ifdef LCF_VIRTUAL
+void check_vmdefault(void)
+{
+    char * deflt;
+    int i;
+    
+    if ( (deflt = cfg_get_strg(cf_options,"vmdefault")) ) {
+	for (i=0; i<image; ++i) {
+	    if (descrs.d.descr[i].flags & FLAG_VMDEFAULT) return;
+	}
+	die("Vmdefault image does not exist.");
+    }
+}
+#endif
+
+
 void check_fallback(void)
 {
     char *start,*end;
@@ -1324,7 +1340,7 @@ static int timestamp = 0;
     if (pass<1) {	/* BIOS_TT logic */
 	MENUTABLE *menu = &menuparams;
 	map_descrs(&descrs, menu->mt_descr, &menuparams.dflcmd);
-	menuparams.raid_dev_mask = raid_mask(menuparams.raid_offset);
+	menuparams.raid_dev_mask = raid_mask((int*)menuparams.raid_offset);
 	memcpy(menuparams.serial_no, serial_no, sizeof(serial_no));
 	memcpy(table+256, &menuparams, sizeof(menuparams));
 	((int*)table)[SECTOR_SIZE/sizeof(int)-2] = crc32(table, SECTOR_SIZE-2*sizeof(int), CRC_POLY1);
