@@ -904,8 +904,8 @@ static int warned = 0, called = 0;
 	if (verbose>=5) {
 	    printf("pf_hard_disk_scan: (%d,%d) %s\n", major, minor, name);
 	}
-	
-	device = major<<8 | (minor&255);
+
+	device = MKDEV(major, minor);
 
 	Dev.delete = 0;
 	if (stat(name, &st) < 0) {
